==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/type/ora_object_grant.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/title_parser'
require 'puppet_x/enterprisemodules/oracle/default_sid'

Puppet::Type.newtype(:ora_object_grant) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access
  extend Puppet_X::EnterpriseModules::Oracle::TitleParser
  include Puppet_X::EnterpriseModules::Oracle::DefaultSid

  validate do
    raise 'object name should use "OWNER.OBJECT"  syntax' unless object_name.split('.').size == 2
  end

  desc <<-DESC
    This type allows you to grant users rights to specified database objects.

    To grant user `SCOTT` `execute` and `debug` rights on on the `sys.dbms_aqin` packgage, you can use:

        ora_object_grant{'SCOTT->sys.dbms_aqin@SID':
          permissions => ['execute', 'debug'],
        }

    If you want to make sure the user only has `execute` rights, use:

        ora_object_grant{'OTHER_USER->sys.dbms_aqin@SID':
           permissions => ['execute'],
        }

    If you want to make sure **no** permissions are granted, you can use an empty array like this:

        ora_object_grant{'OTHER_USER->sys.dbms_aqin':
           permissions => [],
        }
  DESC

  to_get_raw_resources do
    provider(:prefetching).all_resources
  end

  on_create do
    nil # Let the permissions property do its work
  end

  on_modify do
    nil # Let the permissions property do its work
  end

  on_destroy do
    fail "we shouldn't be in on_destroy in ora_object_grant"
  end

  map_title_to_sid(:grantee, :object_name) { /(.+)->(.+)/ }

  parameter :name
  parameter :object_name
  parameter :grantee
  parameter :sid
  property  :permissions
  property  :with_grant_permissions
  property  :common_permissions
  property  :common_with_grant_permissions

  #
  # Because grantee can be either a user or a role, make autorequires on both.
  # It doesn't matter if an autorequire is created to a non existing object.
  #
  ora_autorequire(:ora_user, [:grantee, :object_owner])
  ora_autorequire(:ora_role, :grantee)

  def object_owner
    elements = object_name.split('.')
    elements.size > 1 ? elements.first : ''
  end

  def wildcard_table?
    table_name = object_name.split('.').last
    table_name.include?('%')
  end
end

==> enterprisemodules-ora_config-3.23.4.tar.gz: enterprisemodules-ora_config-3.23.4/lib/puppet/type/ora_object_grant.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/title_parser'
require 'puppet_x/enterprisemodules/oracle/default_sid'

Puppet::Type.newtype(:ora_object_grant) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access
  extend PuppetX::EnterpriseModules::Oracle::TitleParser
  include PuppetX::EnterpriseModules::Oracle::DefaultSid

  validate do
    raise 'object name should use "OWNER.OBJECT"  syntax' unless object_name.split('.').size == 2
  end

  desc <<-DESC
    This type allows you to grant users rights to specified database objects.

    To grant user `SCOTT` `execute` and `debug` rights on on the `sys.dbms_aqin` packgage, you can use:

        ora_object_grant{'SCOTT->sys.dbms_aqin@SID':
          permissions => ['execute', 'debug'],
        }

    If you want to make sure the user only has `execute` rights, use:

        ora_object_grant{'OTHER_USER->sys.dbms_aqin@SID':
           permissions => ['execute'],
        }

    If you want to make sure **no** permissions are granted, you can use an empty array like this:

        ora_object_grant{'OTHER_USER->sys.dbms_aqin':
           permissions => [],
        }
  DESC

  to_get_raw_resources do
    provider(:prefetching).all_resources
  end

  on_create do
    nil # Let the permissions property do its work
  end

  on_modify do
    nil # Let the permissions property do its work
  end

  on_destroy do
    fail "we shouldn't be in on_destroy in ora_object_grant"
  end

  map_title_to_sid(:grantee, :object_name) { /(.+)->(.+)/ }

  parameter :name
  parameter :object_name
  parameter :grantee
  parameter :sid
  property  :permissions
  property  :with_grant_permissions
  property  :common_permissions
  property  :common_with_grant_permissions

  #
  # Because grantee can be either a user or a role, make autorequires on both.
  # It doesn't matter if an autorequire is created to a non existing object.
  #
  ora_autorequire(:ora_user, [:grantee, :object_owner])
  ora_autorequire(:ora_role, :grantee)

  def object_owner
    elements = object_name.split('.')
    elements.size > 1 ? elements.first : ''
  end

  def wildcard_table?
    table_name = object_name.split('.').last
    table_name.include?('%')
  end
end
